(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     93386,       2569]
NotebookOptionsPosition[     84397,       2416]
NotebookOutlinePosition[     84848,       2434]
CellTagsIndexPosition[     84805,       2431]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "for", " ", 
    "\"\<Multiple nutrient transporters enable cells to mitigate a \
rate-affinity tradeoff\>\"", "\[IndentingNewLine]", "by", " ", "Montano"}], 
   "-", 
   RowBox[{"Gutierrez", " ", "et", " ", 
    RowBox[{"al", ".", " ", "Contact"}], " ", 
    RowBox[{"peter", ".", 
     RowBox[{"swain", "@", "ed"}], ".", "ac", ".", "uk"}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.840798064418351*^9, 3.8407980783733473`*^9}, {
  3.8407983008553762`*^9, 3.8407983248395452`*^9}, {3.840802273981291*^9, 
  3.840802276184952*^9}, {3.8414781047847433`*^9, 3.841478132987966*^9}, {
  3.841478266009158*^9, 3.841478268776338*^9}, {3.841725192016671*^9, 
  3.8417251933478937`*^9}, {3.8426172975969687`*^9, 3.84261731727708*^9}, {
  3.851264031059107*^9, 3.851264033219461*^9}, {3.856332752009367*^9, 
  3.856332815279213*^9}},ExpressionUUID->"924e9c81-ef04-4688-93c3-\
7efd89ddaaa2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "ODEs", " ", "for", " ", "four", " ", "states", " ", "of", " ", 
    "transporter"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dTi", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "ri"}], " ", "Ti"}], "+", 
      RowBox[{"re", " ", "Te"}], " ", "-", 
      RowBox[{"fi", " ", "gi", " ", "Ti"}], "+", 
      RowBox[{"bi", " ", "Tpi"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dTpi", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "rpi"}], " ", "Tpi"}], "+", 
      RowBox[{"rpe", " ", "Tpe"}], "+", 
      RowBox[{"fi", " ", "gi", " ", "Ti"}], "-", 
      RowBox[{"bi", " ", "Tpi"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dTe", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "re"}], " ", "Te"}], "+", 
      RowBox[{"ri", " ", "Ti"}], "-", 
      RowBox[{"fe", " ", "ge", " ", "Te"}], "+", 
      RowBox[{"be", " ", "Tpe"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dS", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"dTi", "\[Equal]", "0"}], ",", 
          RowBox[{"dTpi", "\[Equal]", "0"}], ",", 
          RowBox[{"dTe", "\[Equal]", "0"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Tpi", ",", "Ti", ",", "Te"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"tpe", "=", 
     RowBox[{"Tpe", "/.", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"t0", "-", "Tpi", "-", "Ti", "-", "Te", "-", "Tpe"}], 
              ")"}], "/.", 
             RowBox[{"dS", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "\[Equal]", "0"}], ",",
           "Tpe"}], "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\n", 
   RowBox[{"exflux", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "fi"}], " ", "Ti", " ", "gi"}], "+", 
          RowBox[{"bi", " ", "Tpi"}]}], ")"}], "/.", 
        RowBox[{"dS", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/.", 
      RowBox[{"Tpe", "\[Rule]", "tpe"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.840798064418351*^9, 3.8407980783733473`*^9}, {
  3.8407983008553762`*^9, 3.8407983248395452`*^9}, {3.840802273981291*^9, 
  3.840802276184952*^9}, {3.8414781047847433`*^9, 3.841478132987966*^9}, {
  3.841478266009158*^9, 3.841478268776338*^9}, {3.841725192016671*^9, 
  3.8417251933478937`*^9}, {3.8426172975969687`*^9, 3.84261731727708*^9}, {
  3.851264031059107*^9, 3.851264033219461*^9}, {3.856332752009367*^9, 
  3.8563328289314117`*^9}},ExpressionUUID->"b06d9ff6-8877-4719-894e-\
5211727747e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"bi", " ", "fe", " ", "ge", " ", "ri", " ", "rpe"}], "-", 
      RowBox[{"be", " ", "fi", " ", "gi", " ", "re", " ", "rpi"}]}], ")"}], 
    " ", "t0"}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"bi", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"re", "+", "ri"}], ")"}], " ", "rpe"}], "+", 
       RowBox[{"fe", " ", "ge", " ", 
        RowBox[{"(", 
         RowBox[{"ri", "+", "rpe"}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fi", " ", "gi", " ", "re"}], "+", 
       RowBox[{"fe", " ", "ge", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi"}], "+", "ri"}], ")"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"rpe", "+", "rpi"}], ")"}]}], "+", 
    RowBox[{"be", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"bi", " ", 
        RowBox[{"(", 
         RowBox[{"re", "+", "ri"}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"re", "+", "ri"}], ")"}], " ", "rpi"}], "+", 
       RowBox[{"fi", " ", "gi", " ", 
        RowBox[{"(", 
         RowBox[{"re", "+", "rpi"}], ")"}]}]}], ")"}]}]}], ")"}]}]], "Output",\

 CellChangeTimes->{3.840798101037958*^9, 3.8407982284005337`*^9, 
  3.840798332795228*^9, 3.840799570993222*^9, 3.840801575739394*^9, 
  3.840801950447357*^9, 3.8408024144131927`*^9, 3.841222813916884*^9, 
  3.841473373858178*^9, 3.84147604513627*^9, 3.841478160073434*^9, 
  3.841478300481618*^9, 3.8414787227938633`*^9, 3.8417233631553917`*^9, 
  3.8417253103069153`*^9, 3.841730550527749*^9, 3.842617399701201*^9, 
  3.851061390910205*^9, 3.851264055013405*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"1f255aba-caf6-4dd8-b637-6804ac683885"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "flux", " ", "is", " ", "a", " ", "monotonic", " ", "increasing", " ", 
     "function", " ", "ri", " ", "and", " ", "rpe", " ", "and", " ", "a", " ",
      "decreasing", " ", "function", " ", "of", " ", "re", " ", "and", " ", 
     "rpi"}], ";"}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"exflux", ",", "ri"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"exflux", ",", "re"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"exflux", ",", "rpi"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"exflux", ",", "rpe"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8412155495551167`*^9, 3.841215606051896*^9}, {
  3.84121564354872*^9, 3.841215653819499*^9}, {3.841216273687353*^9, 
  3.84121628725421*^9}, {3.841222026993945*^9, 3.8412220491105633`*^9}, {
  3.8414780803281393`*^9, 3.84147809691111*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"bf030863-3ced-49b1-9389-64400c5e6cb7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"bi", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fe", " ", "ge"}], "+", "re"}], ")"}], " ", "rpe"}], "+", 
      RowBox[{"be", " ", "re", " ", 
       RowBox[{"(", 
        RowBox[{"bi", "+", "rpi"}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"bi", " ", "fe", " ", "ge", " ", "rpe"}], "+", 
      RowBox[{"fi", " ", "gi", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"be", " ", "rpi"}], "+", 
         RowBox[{"fe", " ", "ge", " ", 
          RowBox[{"(", 
           RowBox[{"rpe", "+", "rpi"}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
    "t0"}], ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"bi", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"re", "+", "ri"}], ")"}], " ", "rpe"}], "+", 
        RowBox[{"fe", " ", "ge", " ", 
         RowBox[{"(", 
          RowBox[{"ri", "+", "rpe"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi", " ", "re"}], "+", 
        RowBox[{"fe", " ", "ge", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "ri"}], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"rpe", "+", "rpi"}], ")"}]}], "+", 
     RowBox[{"be", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"bi", " ", 
         RowBox[{"(", 
          RowBox[{"re", "+", "ri"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"re", "+", "ri"}], ")"}], " ", "rpi"}], "+", 
        RowBox[{"fi", " ", "gi", " ", 
         RowBox[{"(", 
          RowBox[{"re", "+", "rpi"}], ")"}]}]}], ")"}]}]}], ")"}], 
   "2"]}]], "Output",
 CellChangeTimes->{{3.841215558787139*^9, 3.841215606880433*^9}, 
   3.84121628786961*^9, 3.84122205111405*^9, 3.8412228139594088`*^9, 
   3.841473378109874*^9, 3.8414760451753893`*^9, 3.841478164348919*^9, 
   3.841478304798779*^9, 3.841478722829852*^9, 3.8417233662888727`*^9, 
   3.841725313272375*^9, 3.841730550567127*^9, 3.842617406099082*^9, 
   3.851061393867735*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"cbd02ebe-9ce2-4c83-9a54-4de4c34057b9"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"be", " ", "bi", " ", "ri"}], "+", 
        RowBox[{"bi", " ", "ri", " ", "rpe"}], "+", 
        RowBox[{"be", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "ri"}], ")"}], " ", "rpi"}]}], 
       ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"bi", " ", "fe", " ", "ge", " ", "rpe"}], "+", 
        RowBox[{"fi", " ", "gi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"be", " ", "rpi"}], "+", 
           RowBox[{"fe", " ", "ge", " ", 
            RowBox[{"(", 
             RowBox[{"rpe", "+", "rpi"}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
      "t0"}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"bi", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"re", "+", "ri"}], ")"}], " ", "rpe"}], "+", 
          RowBox[{"fe", " ", "ge", " ", 
           RowBox[{"(", 
            RowBox[{"ri", "+", "rpe"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi", " ", "re"}], "+", 
          RowBox[{"fe", " ", "ge", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fi", " ", "gi"}], "+", "ri"}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"rpe", "+", "rpi"}], ")"}]}], "+", 
       RowBox[{"be", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"bi", " ", 
           RowBox[{"(", 
            RowBox[{"re", "+", "ri"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"re", "+", "ri"}], ")"}], " ", "rpi"}], "+", 
          RowBox[{"fi", " ", "gi", " ", 
           RowBox[{"(", 
            RowBox[{"re", "+", "rpi"}], ")"}]}]}], ")"}]}]}], ")"}], "2"]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.841215558787139*^9, 3.841215606880433*^9}, 
   3.84121628786961*^9, 3.84122205111405*^9, 3.8412228139594088`*^9, 
   3.841473378109874*^9, 3.8414760451753893`*^9, 3.841478164348919*^9, 
   3.841478304798779*^9, 3.841478722829852*^9, 3.8417233662888727`*^9, 
   3.841725313272375*^9, 3.841730550567127*^9, 3.842617406099082*^9, 
   3.851061393892061*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"1aa9c035-43bc-42e3-833e-b72b39c08dc8"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"be", " ", "fi", " ", "gi", " ", "re"}], "+", 
        RowBox[{"bi", " ", "fe", " ", "ge", " ", "ri"}], "+", 
        RowBox[{"be", " ", "bi", " ", 
         RowBox[{"(", 
          RowBox[{"re", "+", "ri"}], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"be", " ", "fi", " ", "gi", " ", "re"}], "+", 
        RowBox[{"fi", " ", "gi", " ", "re", " ", "rpe"}], "+", 
        RowBox[{"fe", " ", "ge", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "ri"}], ")"}], " ", "rpe"}]}], 
       ")"}], " ", "t0"}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"bi", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"re", "+", "ri"}], ")"}], " ", "rpe"}], "+", 
          RowBox[{"fe", " ", "ge", " ", 
           RowBox[{"(", 
            RowBox[{"ri", "+", "rpe"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi", " ", "re"}], "+", 
          RowBox[{"fe", " ", "ge", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fi", " ", "gi"}], "+", "ri"}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"rpe", "+", "rpi"}], ")"}]}], "+", 
       RowBox[{"be", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"bi", " ", 
           RowBox[{"(", 
            RowBox[{"re", "+", "ri"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"re", "+", "ri"}], ")"}], " ", "rpi"}], "+", 
          RowBox[{"fi", " ", "gi", " ", 
           RowBox[{"(", 
            RowBox[{"re", "+", "rpi"}], ")"}]}]}], ")"}]}]}], ")"}], "2"]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.841215558787139*^9, 3.841215606880433*^9}, 
   3.84121628786961*^9, 3.84122205111405*^9, 3.8412228139594088`*^9, 
   3.841473378109874*^9, 3.8414760451753893`*^9, 3.841478164348919*^9, 
   3.841478304798779*^9, 3.841478722829852*^9, 3.8417233662888727`*^9, 
   3.841725313272375*^9, 3.841730550567127*^9, 3.842617406099082*^9, 
   3.85106139391676*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"3f87cec8-964a-46da-8a05-8ba328c77c87"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"be", " ", "fi", " ", "gi", " ", "re"}], "+", 
      RowBox[{"bi", " ", "fe", " ", "ge", " ", "ri"}], "+", 
      RowBox[{"be", " ", "bi", " ", 
       RowBox[{"(", 
        RowBox[{"re", "+", "ri"}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"bi", " ", "fe", " ", "ge", " ", "ri"}], "+", 
      RowBox[{"fi", " ", "gi", " ", "re", " ", "rpi"}], "+", 
      RowBox[{"fe", " ", "ge", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi"}], "+", "ri"}], ")"}], " ", "rpi"}]}], ")"}],
     " ", "t0"}], ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"bi", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"re", "+", "ri"}], ")"}], " ", "rpe"}], "+", 
        RowBox[{"fe", " ", "ge", " ", 
         RowBox[{"(", 
          RowBox[{"ri", "+", "rpe"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi", " ", "re"}], "+", 
        RowBox[{"fe", " ", "ge", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "ri"}], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"rpe", "+", "rpi"}], ")"}]}], "+", 
     RowBox[{"be", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"bi", " ", 
         RowBox[{"(", 
          RowBox[{"re", "+", "ri"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"re", "+", "ri"}], ")"}], " ", "rpi"}], "+", 
        RowBox[{"fi", " ", "gi", " ", 
         RowBox[{"(", 
          RowBox[{"re", "+", "rpi"}], ")"}]}]}], ")"}]}]}], ")"}], 
   "2"]}]], "Output",
 CellChangeTimes->{{3.841215558787139*^9, 3.841215606880433*^9}, 
   3.84121628786961*^9, 3.84122205111405*^9, 3.8412228139594088`*^9, 
   3.841473378109874*^9, 3.8414760451753893`*^9, 3.841478164348919*^9, 
   3.841478304798779*^9, 3.841478722829852*^9, 3.8417233662888727`*^9, 
   3.841725313272375*^9, 3.841730550567127*^9, 3.842617406099082*^9, 
   3.8510613939486103`*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"54f8cf21-7527-4b15-a39c-b944c74513d7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"exflux", "/", "t0"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ri", "->", 
         RowBox[{"1", "/", "e"}]}], ",", 
        RowBox[{"rpe", "->", 
         RowBox[{"1", "/", "e"}]}], ",", 
        RowBox[{"rpi", "->", "0"}], ",", 
        RowBox[{"re", "->", "0"}]}], "}"}]}], "]"}], "/.", 
    RowBox[{"e", "->", "0"}]}], ")"}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.84121611741897*^9, 3.8412161427920723`*^9}, {
  3.8412161773981457`*^9, 3.841216207783485*^9}, {3.841216250680904*^9, 
  3.841216258060298*^9}, {3.841222172332643*^9, 3.841222199760193*^9}, {
  3.841222546239813*^9, 3.841222617858601*^9}, {3.841222693104533*^9, 
  3.841222694109724*^9}, {3.841478232315419*^9, 3.841478233068446*^9}, {
  3.851061398172105*^9, 3.851061400591918*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"94688dc7-8fbc-49cc-b191-cb0d73c701b5"],

Cell[BoxData[
 FractionBox[
  RowBox[{"bi", " ", "fe", " ", "ge"}], 
  RowBox[{"bi", "+", 
   RowBox[{"fe", " ", "ge"}]}]]], "Output",
 CellChangeTimes->{{3.8412225988894377`*^9, 3.841222618919609*^9}, 
   3.841222694804225*^9, 3.841222814052444*^9, 3.84147338252435*^9, 
   3.841476045281494*^9, {3.8414782156335983`*^9, 3.8414782338676643`*^9}, 
   3.841478309054414*^9, 3.841478722959894*^9, 3.8417233726927443`*^9, 
   3.8417305506657667`*^9, 3.842617409564308*^9, 3.851061401059945*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"b4e921e0-899e-4a9b-8c21-517ec60aba85"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "apply", " ", "symmetry", " ", "of", " ", "flipping", " ", 
     "\[IndentingNewLine]", "and", " ", "detailed", " ", 
     RowBox[{"balance", ":", " ", 
      RowBox[{"fe", " ", "bi", " ", "rpe", " ", "ri"}]}]}], " ", "=", " ", 
    RowBox[{"be", " ", "rpi", " ", "fi", " ", "re"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"ef", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"exflux", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"re", "->", "r"}], ",", 
       RowBox[{"ri", "->", "r"}], ",", 
       RowBox[{"rpe", "->", "rp"}], ",", 
       RowBox[{"rpi", "->", "rp"}], ",", 
       RowBox[{"bi", "->", 
        RowBox[{
         RowBox[{"be", "/", "fe"}], " ", "fi"}]}]}], "  ", "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.841473739098584*^9, 3.841473757885275*^9}, {
  3.8414738022561293`*^9, 3.841473870239937*^9}, {3.841473922671011*^9, 
  3.8414739536943483`*^9}, {3.841474095365469*^9, 3.8414740990548067`*^9}, {
  3.8414742626193857`*^9, 3.8414742795055*^9}, {3.84147473421035*^9, 
  3.841474772416298*^9}, {3.841477706031509*^9, 3.8414777273897867`*^9}, {
  3.841478314699703*^9, 3.8414783229469233`*^9}, {3.841725213060598*^9, 
  3.841725221034371*^9}, {3.84172536985083*^9, 3.841725376095611*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"b94d20ba-c28d-4fdc-864f-fba3ed0e73af"],

Cell[BoxData[
 FractionBox[
  RowBox[{"be", " ", "fe", " ", "fi", " ", 
   RowBox[{"(", 
    RowBox[{"ge", "-", "gi"}], ")"}], " ", "r", " ", "rp", " ", "t0"}], 
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["be", "2"], " ", "fi", " ", "r"}], "+", 
   RowBox[{"2", " ", "fe", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"fi", " ", "gi", " ", "r"}], "+", 
      RowBox[{"fe", " ", "ge", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], " ", "rp"}],
    "+", 
   RowBox[{"be", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "fe", " ", "r", " ", "rp"}], "+", 
      RowBox[{"2", " ", "fi", " ", "r", " ", "rp"}], "+", 
      RowBox[{"fe", " ", "fi", " ", 
       RowBox[{"(", 
        RowBox[{"ge", "+", "gi"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}]}]}]]], "Output",
 CellChangeTimes->{
  3.841473758609313*^9, {3.841473835449188*^9, 3.841473871345511*^9}, {
   3.841473942037354*^9, 3.841473954254168*^9}, 3.841474100340481*^9, {
   3.84147476685644*^9, 3.841474775095293*^9}, 3.841476045318989*^9, 
   3.8414777300802317`*^9, 3.8414783236422462`*^9, 3.84147872300049*^9, 
   3.8417233829214067`*^9, 3.841725332120227*^9, 3.8417253769789133`*^9, 
   3.841730550697583*^9, 3.842617415247789*^9, 3.851061420639574*^9, 
   3.851264076483694*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"889837fe-9d8c-4483-add2-d61103d13f44"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "limit", " ", "of", " ", "large", " ", "ge", " ", "when", " ", "gi"}], 
    " ", "=", " ", 
    RowBox[{"c", " ", "ge"}]}], " ", "*)"}], 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{"ef", "/.", " ", 
           RowBox[{"gi", " ", "->", 
            RowBox[{"c", " ", "ge"}]}]}], "]"}], "/.", 
         RowBox[{"ge", "->", 
          RowBox[{"1", "/", "e"}]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"e", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/.", 
     RowBox[{"e", "->", 
      RowBox[{"1", "/", "ge"}]}]}], "/.", 
    RowBox[{"c", "->", 
     RowBox[{"gi", "/", "ge"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8510614283570337`*^9, 3.851061557675683*^9}, {
  3.851062268690027*^9, 3.851062276349476*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"c3a71aa8-b767-4017-af49-0aba25ceaf60"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"be", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      FractionBox["gi", "ge"]}], ")"}], " ", "r", " ", "t0"}], 
   RowBox[{"2", " ", "fe", " ", "gi"}]]}]], "Output",
 CellChangeTimes->{{3.851061514805476*^9, 3.851061529147369*^9}, 
   3.851061562659875*^9, 3.851062277315566*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"01a40970-b947-47a2-a23c-c51bed538782"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "value", " ", "of", " ", "c", " ", "at", " ", "maximal", " ", "flux", " ",
      "when", " ", "gi"}], " ", "=", 
    RowBox[{"c", " ", "ge"}]}], " ", "*)"}], 
  RowBox[{"efmaxsol", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"Simplify", "[", 
            RowBox[{"ef", "/.", 
             RowBox[{"gi", "->", 
              RowBox[{"c", " ", "ge"}]}]}], "]"}], ",", "ge"}], "]"}], "]"}], 
        "==", "0"}], ",", "c"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rp", "->", "r"}], ",", 
       RowBox[{"be", "->", 
        RowBox[{"kd", " ", "fe"}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.851264092100977*^9, 3.851264194869108*^9}, {
  3.851264286243267*^9, 3.85126428957265*^9}, {3.8512643335483627`*^9, 
  3.851264341299692*^9}, {3.851264419543347*^9, 3.8512644256639967`*^9}, {
  3.851264575075149*^9, 
  3.851264596832608*^9}},ExpressionUUID->"571dc8cf-2a61-4bce-ae17-\
03ebcb13325e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"c", "\[Rule]", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c", "\[Rule]", 
     FractionBox[
      RowBox[{"kd", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "r"}], "+", 
         RowBox[{"fe", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"fi", " ", "kd"}], "+", "r"}], ")"}]}]}], ")"}]}], 
      RowBox[{"fe", " ", "fi", " ", 
       SuperscriptBox["ge", "2"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8512640974512987`*^9, 3.85126411349685*^9}, {
   3.851264144435145*^9, 3.851264196122447*^9}, 3.851264291091823*^9, 
   3.851264342134335*^9, 3.851264433062372*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"d654b2cf-2da4-4b15-9564-fc2dbf178214"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"flux", " ", "=", " ", 
    RowBox[{"kc", " ", 
     RowBox[{"dg", "/", 
      RowBox[{"(", 
       RowBox[{"km", " ", "+", " ", "dg"}], ")"}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ef2", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"ef", "/.", 
       RowBox[{"ge", "->", 
        RowBox[{"dg", " ", "+", "gi"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"den", "=", 
     RowBox[{"Denominator", "[", "ef2", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"kc", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Numerator", "[", 
       RowBox[{
        RowBox[{"ef2", "/", "dg"}], "/", "t0"}], "]"}], "/", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"den", ",", "dg", ",", "1"}], "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"km", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"den", ",", "dg", ",", "0"}], "]"}], "/", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"den", ",", "dg", ",", "1"}], "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"kc", " ", "dg", " ", 
      RowBox[{"t0", "/", 
       RowBox[{"(", 
        RowBox[{"km", " ", "+", "dg"}], ")"}]}]}], " ", "-", " ", "ef2"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.841474785668188*^9, 3.841474796142109*^9}, {
  3.84172496925949*^9, 3.841724987978513*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"41049964-0d2a-4f8a-b10a-6033ba4fd2d2"],

Cell[BoxData[
 FractionBox[
  RowBox[{"be", " ", "fi", " ", "r", " ", "rp"}], 
  RowBox[{
   RowBox[{"2", " ", "fe", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}], "+", 
   RowBox[{"be", " ", "fi", " ", 
    RowBox[{"(", 
     RowBox[{"r", "+", "rp"}], ")"}]}]}]]], "Output",
 CellChangeTimes->{3.841474797696459*^9, 3.841476045388983*^9, 
  3.8414768121004753`*^9, 3.841477734924281*^9, 3.8414783270427847`*^9, 
  3.8414787231108522`*^9, 3.841723387505041*^9, 3.841724988746045*^9, 
  3.841725334225338*^9, 3.841725383019071*^9, 3.841730550749543*^9, 
  3.842617417628735*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"d1c90c8e-563b-4d24-b178-32d1e6b495d1"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{"be", "+", 
     RowBox[{"fe", " ", "gi"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"be", " ", "fi", " ", "r"}], "+", 
     RowBox[{"fi", " ", "r", " ", "rp"}], "+", 
     RowBox[{"fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}]}], ")"}]}], 
  
  RowBox[{"fe", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}], "+", 
     RowBox[{"be", " ", "fi", " ", 
      RowBox[{"(", 
       RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.841474797696459*^9, 3.841476045388983*^9, 
  3.8414768121004753`*^9, 3.841477734924281*^9, 3.8414783270427847`*^9, 
  3.8414787231108522`*^9, 3.841723387505041*^9, 3.841724988746045*^9, 
  3.841725334225338*^9, 3.841725383019071*^9, 3.841730550749543*^9, 
  3.842617417648258*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"0a9900c8-0da0-4944-a662-835830b1b6f7"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.841474797696459*^9, 3.841476045388983*^9, 
  3.8414768121004753`*^9, 3.841477734924281*^9, 3.8414783270427847`*^9, 
  3.8414787231108522`*^9, 3.841723387505041*^9, 3.841724988746045*^9, 
  3.841725334225338*^9, 3.841725383019071*^9, 3.841730550749543*^9, 
  3.842617417650442*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"6e0bb4a1-e23b-4c84-9d37-a5380a49f14f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"tradeoff", " ", "with", " ", "fe"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"kc", ",", "fe"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"1", "/", "km"}], ",", "fe"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.841476468880177*^9, 3.841476493393138*^9}, {
  3.841476552738184*^9, 3.841476594028139*^9}, {3.8414777414744577`*^9, 
  3.8414777447257566`*^9}, {3.841478566587598*^9, 3.8414785818650723`*^9}, {
  3.841730798604094*^9, 3.841730803992236*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"9908d898-a12b-499d-bc25-74c6c83e3fb2"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "be", " ", "fi", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", 
    SuperscriptBox["rp", "2"]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "fe", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}], "+", 
      RowBox[{"be", " ", "fi", " ", 
       RowBox[{"(", 
        RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}], "2"]]}]], "Output",
 CellChangeTimes->{{3.84147648286478*^9, 3.841476493973645*^9}, 
   3.841476588233536*^9, 3.841477745519293*^9, 3.841478330217382*^9, 
   3.841478723144657*^9, 3.841725397486506*^9, 3.841730550806757*^9, 
   3.842617420888736*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"82e873ef-9e94-49a5-8db5-2c14bdd65f60"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["fe", "2"], " ", "fi", " ", "gi", " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", 
     SuperscriptBox["rp", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["be", "3"], " ", 
     SuperscriptBox["fi", "2"], " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", "rp"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["be", "2"], " ", "fi", " ", "r", " ", "rp", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "fe", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
       RowBox[{"fi", " ", 
        RowBox[{"(", 
         RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"be", " ", "fe", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "fe", " ", "r", " ", "rp"}], "+", 
       RowBox[{"4", " ", "fi", " ", "r", " ", "rp"}], "+", 
       RowBox[{"fe", " ", "fi", " ", "gi", " ", 
        RowBox[{"(", 
         RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"be", "+", 
       RowBox[{"fe", " ", "gi"}]}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"be", " ", "fi", " ", "r"}], "+", 
       RowBox[{"fi", " ", "r", " ", "rp"}], "+", 
       RowBox[{"fe", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}]}], ")"}], 
     "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.84147648286478*^9, 3.841476493973645*^9}, 
   3.841476588233536*^9, 3.841477745519293*^9, 3.841478330217382*^9, 
   3.841478723144657*^9, 3.841725397486506*^9, 3.841730550806757*^9, 
   3.8426174209543743`*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"a524898f-6649-475c-bbf2-52a09fdd24f4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "derivative", " ", "of", " ", "flux", " ", "can", " ", 
    "change", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"ef2", ",", "fe"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.842617441057555*^9, 3.8426174411249943`*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"b6f4d3a1-78d6-48af-a6df-7fea55907679"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", "be", " ", "dg", " ", "fi", " ", "r", " ", "rp", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["be", "2"], " ", "fi", " ", "r"}], "+", 
      RowBox[{"be", " ", "fi", " ", "r", " ", "rp"}], "-", 
      RowBox[{
       SuperscriptBox["fe", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"dg", "+", "gi"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}]}], ")"}], 
    " ", "t0"}], ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["be", "2"], " ", "fi", " ", "r"}], "+", 
     RowBox[{"2", " ", "fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi", " ", "r"}], "+", 
        RowBox[{"dg", " ", "fe", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
        RowBox[{"fe", " ", "gi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], " ", 
      "rp"}], "+", 
     RowBox[{"be", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"dg", " ", "fe", " ", "fi", " ", 
         RowBox[{"(", 
          RowBox[{"r", "+", "rp"}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fe", " ", "r", " ", "rp"}], "+", 
           RowBox[{"fi", " ", "r", " ", "rp"}], "+", 
           RowBox[{"fe", " ", "fi", " ", "gi", " ", 
            RowBox[{"(", 
             RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}],
    "2"]}]], "Output",
 CellChangeTimes->{3.842617441700067*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"6e0bb4f6-61aa-44ca-8e3a-6801b0e953ad"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"possible", " ", "tradeoff", " ", "with", " ", "fi"}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"kc", ",", "fi"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"1", "/", "km"}], ",", "fi"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.84147663818134*^9, 3.8414766487563972`*^9}, {
  3.841476684700377*^9, 3.8414766858479156`*^9}, {3.8414777492373343`*^9, 
  3.841477753579619*^9}, {3.841730813847521*^9, 3.841730836336108*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"5ae776ca-615d-4b60-86ee-dc72ea6f61f2"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "be", " ", "fe", " ", 
   SuperscriptBox["r", "2"], " ", 
   SuperscriptBox["rp", "2"]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}], "+", 
     RowBox[{"be", " ", "fi", " ", 
      RowBox[{"(", 
       RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}], "2"]]], "Output",
 CellChangeTimes->{3.841476645533374*^9, 3.841476686675271*^9, 
  3.841477753937544*^9, 3.841478332976316*^9, 3.841478723176152*^9, 
  3.841725421693658*^9, 3.8417305508874187`*^9, 3.8426174475786552`*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"445663b8-4c99-4224-b35b-767494e1dfd8"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["fe", "2"], " ", "r", " ", "rp", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"be", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", "rp"}], ")"}]}], "+", 
      RowBox[{"2", " ", "r", " ", "rp"}]}], ")"}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"be", "+", 
      RowBox[{"fe", " ", "gi"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"be", " ", "fi", " ", "r"}], "+", 
       RowBox[{"fi", " ", "r", " ", "rp"}], "+", 
       RowBox[{"fe", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}]}], ")"}], 
     "2"]}]]}]], "Output",
 CellChangeTimes->{3.841476645533374*^9, 3.841476686675271*^9, 
  3.841477753937544*^9, 3.841478332976316*^9, 3.841478723176152*^9, 
  3.841725421693658*^9, 3.8417305508874187`*^9, 3.84261744759866*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"4a12837d-b458-4a82-936f-4858f47e124b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "derivative", " ", "of", " ", "flux", " ", "cannot", " ", 
    "change", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"ef2", ",", "fi"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.842617454175109*^9, 
  3.842617459215167*^9}},ExpressionUUID->"d4ddfbcf-3f55-4396-abd1-\
c5f69bd313b7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", "be", " ", "dg", " ", 
    SuperscriptBox["fe", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"be", "+", 
      RowBox[{"fe", " ", 
       RowBox[{"(", 
        RowBox[{"dg", "+", "gi"}], ")"}]}]}], ")"}], " ", 
    SuperscriptBox["r", "2"], " ", 
    SuperscriptBox["rp", "2"], " ", "t0"}], ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["be", "2"], " ", "fi", " ", "r"}], "+", 
     RowBox[{"2", " ", "fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi", " ", "r"}], "+", 
        RowBox[{"dg", " ", "fe", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
        RowBox[{"fe", " ", "gi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], " ", 
      "rp"}], "+", 
     RowBox[{"be", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"dg", " ", "fe", " ", "fi", " ", 
         RowBox[{"(", 
          RowBox[{"r", "+", "rp"}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fe", " ", "r", " ", "rp"}], "+", 
           RowBox[{"fi", " ", "r", " ", "rp"}], "+", 
           RowBox[{"fe", " ", "fi", " ", "gi", " ", 
            RowBox[{"(", 
             RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}],
    "2"]}]], "Output",
 CellChangeTimes->{3.842617455151276*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"62e424ca-be27-43bd-a68d-7b3388762e5d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"tradeoff", " ", "with", " ", "r"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"kc", ",", "r"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"1", "/", "km"}], ",", "r"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.841476534590863*^9, 3.841476536357061*^9}, {
  3.841476615614756*^9, 3.8414766303626137`*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"1a073019-4273-4117-9261-f6cdffaa9a40"],

Cell[BoxData[
 FractionBox[
  RowBox[{"be", " ", 
   SuperscriptBox["fi", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"be", "+", 
     RowBox[{"2", " ", "fe", " ", "gi"}]}], ")"}], " ", 
   SuperscriptBox["rp", "2"]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}], "+", 
     RowBox[{"be", " ", "fi", " ", 
      RowBox[{"(", 
       RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}], "2"]]], "Output",
 CellChangeTimes->{3.841476536775927*^9, 3.8414766176362467`*^9, 
  3.8414766752184772`*^9, 3.8414777670628433`*^9, 3.841478345700045*^9, 
  3.841478723217188*^9, 3.8417254418095818`*^9, 3.841730550920392*^9, 
  3.8426174674390717`*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"94bc3816-8899-4ae5-aed8-3150097afe7a"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"fe", " ", "fi", " ", "rp", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["be", "2"], " ", "fi"}], "+", 
      RowBox[{"be", " ", "fi", " ", "rp"}], "+", 
      RowBox[{"2", " ", "fe", " ", "fi", " ", "gi", " ", "rp"}], "+", 
      RowBox[{"be", " ", "fe", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi"}], "+", "rp"}], ")"}]}]}], ")"}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"be", "+", 
      RowBox[{"fe", " ", "gi"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"be", " ", "fi", " ", "r"}], "+", 
       RowBox[{"fi", " ", "r", " ", "rp"}], "+", 
       RowBox[{"fe", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}]}], ")"}], 
     "2"]}]]}]], "Output",
 CellChangeTimes->{3.841476536775927*^9, 3.8414766176362467`*^9, 
  3.8414766752184772`*^9, 3.8414777670628433`*^9, 3.841478345700045*^9, 
  3.841478723217188*^9, 3.8417254418095818`*^9, 3.841730550920392*^9, 
  3.842617467457099*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"3177a9e3-778e-43b3-9308-0e53731105f0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "derivative", " ", "of", " ", "flux", " ", "cannot", " ", 
    "change", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"ef2", ",", "r"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.842617477113982*^9, 3.842617477395268*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"8070985d-7ae3-4c2c-b1ec-213cc8187ede"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"be", " ", "dg", " ", 
    SuperscriptBox["fe", "2"], " ", 
    SuperscriptBox["fi", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "fe", " ", "gi", " ", 
       RowBox[{"(", 
        RowBox[{"dg", "+", "gi"}], ")"}]}], "+", 
      RowBox[{"be", " ", 
       RowBox[{"(", 
        RowBox[{"dg", "+", 
         RowBox[{"2", " ", "gi"}]}], ")"}]}]}], ")"}], " ", 
    SuperscriptBox["rp", "2"], " ", "t0"}], ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["be", "2"], " ", "fi", " ", "r"}], "+", 
     RowBox[{"2", " ", "fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi", " ", "r"}], "+", 
        RowBox[{"dg", " ", "fe", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
        RowBox[{"fe", " ", "gi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], " ", 
      "rp"}], "+", 
     RowBox[{"be", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"dg", " ", "fe", " ", "fi", " ", 
         RowBox[{"(", 
          RowBox[{"r", "+", "rp"}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fe", " ", "r", " ", "rp"}], "+", 
           RowBox[{"fi", " ", "r", " ", "rp"}], "+", 
           RowBox[{"fe", " ", "fi", " ", "gi", " ", 
            RowBox[{"(", 
             RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}],
    "2"]}]], "Output",
 CellChangeTimes->{3.842617478030267*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"bb0fb9af-e37a-4439-94af-323393405de1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"possible", " ", "tradeoff", " ", "with", " ", "rp"}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"kc", ",", "rp"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"1", "/", "km"}], ",", "rp"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8414766573289948`*^9, 3.841476663865271*^9}, {
  3.841476722556962*^9, 3.841476723771834*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"7d9685b3-0ae6-4cb3-b901-410e32455761"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["be", "2"], " ", 
   SuperscriptBox["fi", "2"], " ", 
   SuperscriptBox["r", "2"]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}], "+", 
     RowBox[{"be", " ", "fi", " ", 
      RowBox[{"(", 
       RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}], "2"]]], "Output",
 CellChangeTimes->{3.8414766646010437`*^9, 3.8414767250716457`*^9, 
  3.841477769931594*^9, 3.841478348309183*^9, 3.841478723250979*^9, 
  3.841725445826157*^9, 3.8417305509316874`*^9, 3.8426174832951193`*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"bec51ffb-b92b-4bd5-b936-2a02d12d0669"],

Cell[BoxData[
 FractionBox[
  RowBox[{"be", " ", "fe", " ", "fi", " ", "r", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"be", " ", "fi"}], "-", 
     RowBox[{"fi", " ", "r"}], "+", 
     RowBox[{"fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}]}], 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{"be", "+", 
     RowBox[{"fe", " ", "gi"}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"be", " ", "fi", " ", "r"}], "+", 
      RowBox[{"fi", " ", "r", " ", "rp"}], "+", 
      RowBox[{"fe", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}]}], ")"}], 
    "2"]}]]], "Output",
 CellChangeTimes->{3.8414766646010437`*^9, 3.8414767250716457`*^9, 
  3.841477769931594*^9, 3.841478348309183*^9, 3.841478723250979*^9, 
  3.841725445826157*^9, 3.8417305509316874`*^9, 3.842617483311789*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"a1a359df-a10d-424e-9647-f996ba288024"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "derivative", " ", "of", " ", "flux", " ", "cannot", " ", 
    "change", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"ef2", ",", "rp"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8426174931453333`*^9, 3.8426174954291763`*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"104fb590-ca19-4489-ab8c-a5474e549b5e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["be", "2"], " ", "dg", " ", "fe", " ", 
    SuperscriptBox["fi", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "be"}], "+", 
      RowBox[{"fe", " ", 
       RowBox[{"(", 
        RowBox[{"dg", "+", 
         RowBox[{"2", " ", "gi"}]}], ")"}]}]}], ")"}], " ", 
    SuperscriptBox["r", "2"], " ", "t0"}], ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["be", "2"], " ", "fi", " ", "r"}], "+", 
     RowBox[{"2", " ", "fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi", " ", "r"}], "+", 
        RowBox[{"dg", " ", "fe", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
        RowBox[{"fe", " ", "gi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], " ", 
      "rp"}], "+", 
     RowBox[{"be", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"dg", " ", "fe", " ", "fi", " ", 
         RowBox[{"(", 
          RowBox[{"r", "+", "rp"}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fe", " ", "r", " ", "rp"}], "+", 
           RowBox[{"fi", " ", "r", " ", "rp"}], "+", 
           RowBox[{"fe", " ", "fi", " ", "gi", " ", 
            RowBox[{"(", 
             RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}],
    "2"]}]], "Output",
 CellChangeTimes->{3.842617495976783*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"c68c0725-eada-453d-91e6-98c82e036c0b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"possible", " ", "tradeoff", " ", "with", " ", "be"}], "  ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"kc", ",", "be"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"1", "/", "km"}], ",", "be"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.841476747171925*^9, 3.841476753010676*^9}, {
  3.841479058877761*^9, 3.841479063356344*^9}, {3.841479209643456*^9, 
  3.841479210056999*^9}, {3.8414793478930407`*^9, 3.841479348387795*^9}, {
  3.84172545307778*^9, 3.8417254591640663`*^9}, {3.841730478327395*^9, 
  3.841730478619487*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"43bc7323-b15e-4926-8c57-05f25f7e518f"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "fe", " ", "fi", " ", "r", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", 
   SuperscriptBox["rp", "2"]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}], "+", 
     RowBox[{"be", " ", "fi", " ", 
      RowBox[{"(", 
       RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}], "2"]]], "Output",
 CellChangeTimes->{3.841476753510763*^9, 3.8414777970112057`*^9, 
  3.841478357308999*^9, 3.841478723291882*^9, 3.841479063800206*^9, 
  3.841725459757464*^9, 3.841730550988388*^9, 3.8426174999676437`*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"9cabd51b-04b2-46d8-b1ff-aab3a4461679"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", "be", " ", "fe", " ", "fi", " ", "r", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}], "+", 
        RowBox[{
         SuperscriptBox["be", "2"], " ", 
         SuperscriptBox["fi", "2"], " ", "r", " ", 
         RowBox[{"(", 
          RowBox[{"r", "+", "rp"}], ")"}]}], "+", 
        RowBox[{"fe", " ", "rp", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "r", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "r", " ", "rp"}], "+", 
              RowBox[{"fi", " ", "gi", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "r"}], "+", "rp"}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"fe", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "r", " ", "rp"}], "+", 
              RowBox[{"fi", " ", "gi", " ", 
               RowBox[{"(", 
                RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"be", "+", 
         RowBox[{"fe", " ", "gi"}]}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"be", " ", "fi", " ", "r"}], "+", 
         RowBox[{"fi", " ", "r", " ", "rp"}], "+", 
         RowBox[{"fe", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", "rp"}]}], 
        ")"}], "2"]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.841476753510763*^9, 3.8414777970112057`*^9, 
  3.841478357308999*^9, 3.841478723291882*^9, 3.841479063800206*^9, 
  3.841725459757464*^9, 3.841730550988388*^9, 3.842617500024276*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"8068b907-b3e1-4dc7-80ff-7570d2b2be5c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "derivative", " ", "of", " ", "flux", " ", "cannot", " ", 
    "change", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"ef2", ",", "be"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8426175066567163`*^9, 3.842617507601658*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"bb2f8534-9250-470d-bf47-347440970eab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", "dg", " ", "fe", " ", "fi", " ", "r", " ", "rp", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["be", "2"]}], " ", "fi", " ", "r"}], "+", 
      RowBox[{"fe", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi", " ", "r"}], "+", 
         RowBox[{"dg", " ", "fe", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
         RowBox[{"fe", " ", "gi", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], " ", 
       "rp"}]}], ")"}], " ", "t0"}], ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["be", "2"], " ", "fi", " ", "r"}], "+", 
     RowBox[{"2", " ", "fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi", " ", "r"}], "+", 
        RowBox[{"dg", " ", "fe", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
        RowBox[{"fe", " ", "gi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], " ", 
      "rp"}], "+", 
     RowBox[{"be", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"dg", " ", "fe", " ", "fi", " ", 
         RowBox[{"(", 
          RowBox[{"r", "+", "rp"}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fe", " ", "r", " ", "rp"}], "+", 
           RowBox[{"fi", " ", "r", " ", "rp"}], "+", 
           RowBox[{"fe", " ", "fi", " ", "gi", " ", 
            RowBox[{"(", 
             RowBox[{"r", "+", "rp"}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}],
    "2"]}]], "Output",
 CellChangeTimes->{3.842617508756814*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"8f782904-7ae0-4ca0-9982-e588c9545769"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
   "*"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.841479276455674*^9, 3.841479282721162*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"3a4f5e8c-3ba2-48de-a864-e157ae41bcbe"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"let", " ", "r"}], "=", " ", "rp"}], "  ", "*)"}], "\n", 
  RowBox[{
   RowBox[{"kcs", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"kc", "/.", 
      RowBox[{"{", 
       RowBox[{"rp", "->", "r"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"kms", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"km", "/.", 
      RowBox[{"{", 
       RowBox[{"rp", "->", "r"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"efs", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"ef2", "/.", 
      RowBox[{"rp", "->", "r"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"kcs", " ", "dg", " ", 
      RowBox[{"t0", "/", 
       RowBox[{"(", 
        RowBox[{"kms", " ", "+", "dg"}], ")"}]}]}], " ", "-", " ", "efs"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.841214089523472*^9, 3.841214094719777*^9}, {
  3.841475247064941*^9, 3.841475272548086*^9}, {3.841476218304597*^9, 
  3.84147623424825*^9}, {3.841477803722145*^9, 3.8414778267517347`*^9}, {
  3.841479420973372*^9, 3.841479472162519*^9}, {3.841479720550786*^9, 
  3.8414797367960157`*^9}, {3.841724237218997*^9, 3.841724237802991*^9}, {
  3.841725017938664*^9, 3.841725064907239*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"048ba147-2f2c-4075-b303-4fe4e18356b1"],

Cell[BoxData[
 FractionBox[
  RowBox[{"be", " ", "fi", " ", "r"}], 
  RowBox[{
   RowBox[{"2", " ", "be", " ", "fi"}], "+", 
   RowBox[{"2", " ", "fe", " ", "fi", " ", "gi"}], "+", 
   RowBox[{"2", " ", "fe", " ", "r"}]}]]], "Output",
 CellChangeTimes->{
  3.841213386095619*^9, 3.8412134731355658`*^9, 3.84121378470765*^9, 
   3.841222816187944*^9, 3.8412233606548157`*^9, {3.841223424104002*^9, 
   3.841223443812553*^9}, {3.84122362740034*^9, 3.8412236329102287`*^9}, {
   3.841223697648037*^9, 3.8412237275575867`*^9}, {3.841223804860333*^9, 
   3.841223812454001*^9}, 3.841474529248126*^9, {3.841474906838401*^9, 
   3.841474925115494*^9}, 3.841475179812676*^9, 3.841475223608458*^9, 
   3.841475296941309*^9, 3.841476045922596*^9, 3.841476398281169*^9, {
   3.8414778224571857`*^9, 3.841477827360403*^9}, 3.841478723359816*^9, {
   3.841479463523589*^9, 3.841479472930002*^9}, 3.841479737452704*^9, 
   3.841723400076675*^9, 3.841724238663746*^9, {3.841725046884399*^9, 
   3.841725065288334*^9}, 3.841725324327848*^9, 3.841725476274201*^9, 
   3.841730551063711*^9, 3.8426175128410273`*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"df2963e3-51eb-4bab-bf0c-2976e86f9f3a"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"be", "+", 
     RowBox[{"fe", " ", "gi"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"be", " ", "fi"}], "+", 
     RowBox[{"fi", " ", "r"}], "+", 
     RowBox[{"fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}]}], 
  RowBox[{"fe", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"be", " ", "fi"}], "+", 
     RowBox[{"fe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}]}]]], "Output",\

 CellChangeTimes->{
  3.841213386095619*^9, 3.8412134731355658`*^9, 3.84121378470765*^9, 
   3.841222816187944*^9, 3.8412233606548157`*^9, {3.841223424104002*^9, 
   3.841223443812553*^9}, {3.84122362740034*^9, 3.8412236329102287`*^9}, {
   3.841223697648037*^9, 3.8412237275575867`*^9}, {3.841223804860333*^9, 
   3.841223812454001*^9}, 3.841474529248126*^9, {3.841474906838401*^9, 
   3.841474925115494*^9}, 3.841475179812676*^9, 3.841475223608458*^9, 
   3.841475296941309*^9, 3.841476045922596*^9, 3.841476398281169*^9, {
   3.8414778224571857`*^9, 3.841477827360403*^9}, 3.841478723359816*^9, {
   3.841479463523589*^9, 3.841479472930002*^9}, 3.841479737452704*^9, 
   3.841723400076675*^9, 3.841724238663746*^9, {3.841725046884399*^9, 
   3.841725065288334*^9}, 3.841725324327848*^9, 3.841725476274201*^9, 
   3.841730551063711*^9, 3.842617512847251*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"d854acfa-432f-4333-83e4-34c7954b57fb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"be", " ", "dg", " ", "fe", " ", "fi", " ", "r", " ", "t0"}], 
   ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["be", "2"], " ", "fi"}], "+", 
      RowBox[{"fe", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi", " ", "r"}], "+", 
         RowBox[{"dg", " ", "fe", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
         RowBox[{"fe", " ", "gi", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"be", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"dg", " ", "fe", " ", "fi"}], "+", 
         RowBox[{"fi", " ", "r"}], "+", 
         RowBox[{"fe", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "fi", " ", "gi"}], "+", "r"}], ")"}]}]}], 
        ")"}]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.841213386095619*^9, 3.8412134731355658`*^9, 3.84121378470765*^9, 
   3.841222816187944*^9, 3.8412233606548157`*^9, {3.841223424104002*^9, 
   3.841223443812553*^9}, {3.84122362740034*^9, 3.8412236329102287`*^9}, {
   3.841223697648037*^9, 3.8412237275575867`*^9}, {3.841223804860333*^9, 
   3.841223812454001*^9}, 3.841474529248126*^9, {3.841474906838401*^9, 
   3.841474925115494*^9}, 3.841475179812676*^9, 3.841475223608458*^9, 
   3.841475296941309*^9, 3.841476045922596*^9, 3.841476398281169*^9, {
   3.8414778224571857`*^9, 3.841477827360403*^9}, 3.841478723359816*^9, {
   3.841479463523589*^9, 3.841479472930002*^9}, 3.841479737452704*^9, 
   3.841723400076675*^9, 3.841724238663746*^9, {3.841725046884399*^9, 
   3.841725065288334*^9}, 3.841725324327848*^9, 3.841725476274201*^9, 
   3.841730551063711*^9, 3.842617512874806*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"ed74cad0-3330-4e53-a10e-4827d877c3d2"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.841213386095619*^9, 3.8412134731355658`*^9, 3.84121378470765*^9, 
   3.841222816187944*^9, 3.8412233606548157`*^9, {3.841223424104002*^9, 
   3.841223443812553*^9}, {3.84122362740034*^9, 3.8412236329102287`*^9}, {
   3.841223697648037*^9, 3.8412237275575867`*^9}, {3.841223804860333*^9, 
   3.841223812454001*^9}, 3.841474529248126*^9, {3.841474906838401*^9, 
   3.841474925115494*^9}, 3.841475179812676*^9, 3.841475223608458*^9, 
   3.841475296941309*^9, 3.841476045922596*^9, 3.841476398281169*^9, {
   3.8414778224571857`*^9, 3.841477827360403*^9}, 3.841478723359816*^9, {
   3.841479463523589*^9, 3.841479472930002*^9}, 3.841479737452704*^9, 
   3.841723400076675*^9, 3.841724238663746*^9, {3.841725046884399*^9, 
   3.841725065288334*^9}, 3.841725324327848*^9, 3.841725476274201*^9, 
   3.841730551063711*^9, 3.842617512877041*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"44dc4eef-3dc1-4383-9487-14e4cae3fc03"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"tradeoff", " ", "with", " ", "fe"}], "  ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"kcs", ",", "fe"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"1", "/", "kms"}], ",", "fe"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8414795034810038`*^9, 3.84147951307742*^9}, {
   3.84172562882626*^9, 3.841725636284844*^9}, 3.8417309341217527`*^9},
 CellLabel->"In[37]:=",ExpressionUUID->"83b3b5bd-d0b4-4240-ba4c-7918208b5890"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"be", " ", "fi", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"be", " ", "fi"}], "+", 
       RowBox[{"fe", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], 
     "2"]}]]}]], "Output",
 CellChangeTimes->{{3.841479508548483*^9, 3.841479515261677*^9}, 
   3.841723405686021*^9, 3.8417254801744747`*^9, 3.841730551103104*^9, 
   3.842617515866065*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"a35f2669-9f6a-48d3-9ef1-3798ede66c1f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["be", "3"], " ", 
     SuperscriptBox["fi", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["fe", "2"], " ", "fi", " ", "gi", " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
    RowBox[{"be", " ", "fe", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "fi", " ", "r"}], "+", 
       RowBox[{"fe", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["be", "2"], " ", "fi", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fi", " ", "r"}], "+", 
       RowBox[{"2", " ", "fe", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}]}]}], ")"}], 
  "/", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"be", "+", 
       RowBox[{"fe", " ", "gi"}]}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"be", " ", "fi"}], "+", 
       RowBox[{"fi", " ", "r"}], "+", 
       RowBox[{"fe", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], "2"]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.841479508548483*^9, 3.841479515261677*^9}, 
   3.841723405686021*^9, 3.8417254801744747`*^9, 3.841730551103104*^9, 
   3.842617515895883*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"1705b2b2-c557-478c-bc84-688b1e719ed8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "derivative", " ", "of", " ", "flux", " ", "can", " ", 
    "change", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"efs", ",", "fe"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.841725091984872*^9, 3.841725093233678*^9}, {
  3.8417256447819757`*^9, 3.841725655859585*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"7b1341f2-d4c3-4ff3-af82-3f07f8668cfd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"be", " ", "dg", " ", "fi", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["be", "2"], " ", "fi"}], "+", 
      RowBox[{"be", " ", "fi", " ", "r"}], "-", 
      RowBox[{
       SuperscriptBox["fe", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"dg", "+", "gi"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], " ", "t0"}],
    ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["be", "2"], " ", "fi"}], "+", 
       RowBox[{"fe", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi", " ", "r"}], "+", 
          RowBox[{"dg", " ", "fe", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
          RowBox[{"fe", " ", "gi", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"be", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"dg", " ", "fe", " ", "fi"}], "+", 
          RowBox[{"fi", " ", "r"}], "+", 
          RowBox[{"fe", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "fi", " ", "gi"}], "+", "r"}], ")"}]}]}], 
         ")"}]}]}], ")"}], "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.841725093791459*^9, 3.8417254868732347`*^9, 
  3.841730551171014*^9, 3.8426175181213017`*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"ca389e68-265f-428e-94f1-3227883c63e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"tradeoff", " ", "with", " ", "fi"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"kcs", ",", "fi"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"1", "/", "kms"}], ",", "fi"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.841477167001481*^9, 3.8414771809628057`*^9}, {
  3.841477842995348*^9, 3.8414778469775257`*^9}, {3.84147948714624*^9, 
  3.841479496427311*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"75fada25-94e7-4b7f-80dd-7d454f6f33bb"],

Cell[BoxData[
 FractionBox[
  RowBox[{"be", " ", "fe", " ", 
   SuperscriptBox["r", "2"]}], 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"be", " ", "fi"}], "+", 
      RowBox[{"fe", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], 
    "2"]}]]], "Output",
 CellChangeTimes->{
  3.841477174107298*^9, 3.841477847435437*^9, 3.8414787236431093`*^9, {
   3.841479493085647*^9, 3.841479518120866*^9}, 3.841723409511919*^9, 
   3.841725491163858*^9, 3.841730551180051*^9, 3.842617520612006*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"fa061eab-0e79-4bf1-bf11-bfc334f6dc4d"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["fe", "2"], " ", 
    SuperscriptBox["r", "2"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"be", "+", 
      RowBox[{"fe", " ", "gi"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"be", " ", "fi"}], "+", 
       RowBox[{"fi", " ", "r"}], "+", 
       RowBox[{"fe", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], 
     "2"]}]]}]], "Output",
 CellChangeTimes->{
  3.841477174107298*^9, 3.841477847435437*^9, 3.8414787236431093`*^9, {
   3.841479493085647*^9, 3.841479518120866*^9}, 3.841723409511919*^9, 
   3.841725491163858*^9, 3.841730551180051*^9, 3.842617520621173*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"e1759fe0-c57a-4e2d-929f-ae1138668d47"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "but", " ", "derivative", " ", "of", " ", "flux", " ", "cannot", " ", 
     "change", " ", "sign"}], " ", ";", " ", 
    RowBox[{"fi", " ", 
     RowBox[{"maximal", " ", "?"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"efs", ",", "fi"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.841724336431953*^9, 3.841724370395846*^9}, {
  3.841731610834552*^9, 3.841731616751582*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"6da88d09-2d47-44ec-9d0b-910de6d2728a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"be", " ", "dg", " ", 
    SuperscriptBox["fe", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"be", "+", 
      RowBox[{"fe", " ", 
       RowBox[{"(", 
        RowBox[{"dg", "+", "gi"}], ")"}]}]}], ")"}], " ", 
    SuperscriptBox["r", "2"], " ", "t0"}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["be", "2"], " ", "fi"}], "+", 
       RowBox[{"fe", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi", " ", "r"}], "+", 
          RowBox[{"dg", " ", "fe", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
          RowBox[{"fe", " ", "gi", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"be", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"dg", " ", "fe", " ", "fi"}], "+", 
          RowBox[{"fi", " ", "r"}], "+", 
          RowBox[{"fe", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "fi", " ", "gi"}], "+", "r"}], ")"}]}]}], 
         ")"}]}]}], ")"}], "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.841724337416782*^9, 3.841725497081234*^9, 
  3.841730551237265*^9, 3.842617523438714*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"f2ab2749-bf0e-4f19-a891-1a9a677a4bf0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"tradeoff", " ", "with", " ", "be"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"kcs", ",", "be"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"1", "/", "kms"}], ",", "be"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.841479535465026*^9, 3.8414795441500587`*^9}, {
  3.841725587550446*^9, 3.841725606652136*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"bd4a7575-8426-4c0d-8077-c5a8be1e72b1"],

Cell[BoxData[
 FractionBox[
  RowBox[{"fe", " ", "fi", " ", "r", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"be", " ", "fi"}], "+", 
      RowBox[{"fe", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], 
    "2"]}]]], "Output",
 CellChangeTimes->{3.8414795448193617`*^9, 3.841723418512617*^9, 
  3.8417255922455387`*^9, 3.8417305512799397`*^9, 3.842617526000564*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"5f88e300-86df-457e-b65f-7d403c26d62f"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"fe", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["be", "2"], " ", 
       SuperscriptBox["fi", "2"]}], "+", 
      RowBox[{"2", " ", "be", " ", "fe", " ", "fi", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
      RowBox[{"fe", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", 
          SuperscriptBox["r", "2"]}], "+", 
         RowBox[{"fe", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}], "2"]}]}], 
        ")"}]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"be", "+", 
       RowBox[{"fe", " ", "gi"}]}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"be", " ", "fi"}], "+", 
       RowBox[{"fi", " ", "r"}], "+", 
       RowBox[{"fe", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], 
     "2"]}]]}]], "Output",
 CellChangeTimes->{3.8414795448193617`*^9, 3.841723418512617*^9, 
  3.8417255922455387`*^9, 3.8417305512799397`*^9, 3.842617526021871*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"eb505567-1512-4d95-b6f8-99e9a9d77109"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "and", " ", "derivative", " ", "of", " ", "flux", " ", "can", " ", 
    "change", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"efs", ",", "be"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8417242887776937`*^9, 3.8417243258344584`*^9}, {
  3.841725596752211*^9, 3.84172559766343*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"ea80bdc5-cdc9-41de-b339-d8a6b0d795b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"dg", " ", "fe", " ", "fi", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["be", "2"]}], " ", "fi"}], "+", 
      RowBox[{"fe", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi", " ", "r"}], "+", 
         RowBox[{"dg", " ", "fe", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
         RowBox[{"fe", " ", "gi", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}]}]}], 
     ")"}], " ", "t0"}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["be", "2"], " ", "fi"}], "+", 
       RowBox[{"fe", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi", " ", "r"}], "+", 
          RowBox[{"dg", " ", "fe", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
          RowBox[{"fe", " ", "gi", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"be", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"dg", " ", "fe", " ", "fi"}], "+", 
          RowBox[{"fi", " ", "r"}], "+", 
          RowBox[{"fe", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "fi", " ", "gi"}], "+", "r"}], ")"}]}]}], 
         ")"}]}]}], ")"}], "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.841724300398941*^9, 3.841725598157753*^9, 
  3.8417305513393593`*^9, 3.842617529092575*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"0cc7b246-662e-4142-b3c9-d1e8d91961c3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"tradeoff", " ", "with", " ", "r"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"kcs", ",", "r"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"1", "/", "kms"}], ",", "r"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8414795647151337`*^9, 3.841479568540127*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"0e43c2f4-f950-4ff0-885d-35af0c598a05"],

Cell[BoxData[
 FractionBox[
  RowBox[{"be", " ", 
   SuperscriptBox["fi", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"be", "+", 
     RowBox[{"fe", " ", "gi"}]}], ")"}]}], 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"be", " ", "fi"}], "+", 
      RowBox[{"fe", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], 
    "2"]}]]], "Output",
 CellChangeTimes->{3.841479569241829*^9, 3.841723422978016*^9, 
  3.841730551348529*^9, 3.842617531795332*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"c970d07d-4fec-4840-9f22-e344d7feaeed"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"fe", " ", 
    SuperscriptBox["fi", "2"]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"be", " ", "fi"}], "+", 
      RowBox[{"fi", " ", "r"}], "+", 
      RowBox[{"fe", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}], 
    "2"]]}]], "Output",
 CellChangeTimes->{3.841479569241829*^9, 3.841723422978016*^9, 
  3.841730551348529*^9, 3.842617531814945*^9},
 CellLabel->"Out[47]=",ExpressionUUID->"fdb15631-5758-435a-95f6-f955d7354da2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "but", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"efs", ",", "r"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.841724222334382*^9, 3.841724275152905*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"d42b1db2-b558-412c-8ca9-2ef779bd6982"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"be", " ", "dg", " ", "fe", " ", 
    SuperscriptBox["fi", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"be", "+", 
      RowBox[{"fe", " ", "gi"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"be", "+", 
      RowBox[{"fe", " ", 
       RowBox[{"(", 
        RowBox[{"dg", "+", "gi"}], ")"}]}]}], ")"}], " ", "t0"}], ")"}], "/", 
  
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["be", "2"], " ", "fi"}], "+", 
       RowBox[{"fe", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"fi", " ", "gi", " ", "r"}], "+", 
          RowBox[{"dg", " ", "fe", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}], "+", 
          RowBox[{"fe", " ", "gi", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fi", " ", "gi"}], "+", "r"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"be", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"dg", " ", "fe", " ", "fi"}], "+", 
          RowBox[{"fi", " ", "r"}], "+", 
          RowBox[{"fe", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "fi", " ", "gi"}], "+", "r"}], ")"}]}]}], 
         ")"}]}]}], ")"}], "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.841724245025741*^9, 3.8417242756404667`*^9}, 
   3.84173055140427*^9, 3.8426175347813063`*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"8b5ec658-7fa2-4040-82c2-8293974171b3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"km", " ", "in", " ", "terms", " ", "of", " ", "kc"}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"kms", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"kcc", "\[Equal]", "kcs"}], ",", "fi"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8414799407150507`*^9, 3.84147999934982*^9}, 
   3.841723493449684*^9},
 CellLabel->"In[49]:=",ExpressionUUID->"b5138c99-1841-429b-868d-e018940649b0"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"be", "+", 
     RowBox[{"fe", " ", "gi"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"be", "+", 
     RowBox[{"2", " ", "kcc"}]}], ")"}]}], 
  RowBox[{"be", " ", "fe"}]]], "Output",
 CellChangeTimes->{{3.8414799629050627`*^9, 3.84148000262659*^9}, {
   3.8417234652379513`*^9, 3.841723494035986*^9}, 3.841730551469071*^9, 
   3.842617538591076*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"7f6cdc62-df1a-4a32-9e05-edef3c2ea9ed"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "max", " ", "and", " ", "min", " ", "values", " ", "of", " ", "Km"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8417236107313347`*^9, 3.841723621053018*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"6058b5a8-f78c-4757-9fd1-3b0ccefb6fa4"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{"kms", "/.", 
   RowBox[{"r", "->", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"kms", "/.", 
    RowBox[{"r", "->", 
     RowBox[{"1", "/", "e"}]}]}], "]"}], "/.", 
  RowBox[{"e", "->", "0"}]}]}], "Input",
 CellChangeTimes->{{3.841723628759852*^9, 3.841723652527306*^9}},
 CellLabel->"In[50]:=",ExpressionUUID->"405fea11-26c7-4ba1-aa07-76f6b5cf6a7d"],

Cell[BoxData[
 RowBox[{
  FractionBox["be", "fe"], "+", "gi"}]], "Output",
 CellChangeTimes->{{3.841723639245008*^9, 3.8417236531818333`*^9}, 
   3.8417305515012093`*^9, 3.842617544744431*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"fd9ac717-b1a8-481d-b259-72f6f0de144d"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"fe", "+", "fi"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"be", "+", 
     RowBox[{"fe", " ", "gi"}]}], ")"}]}], 
  SuperscriptBox["fe", "2"]]], "Output",
 CellChangeTimes->{{3.841723639245008*^9, 3.8417236531818333`*^9}, 
   3.8417305515012093`*^9, 3.842617544746696*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"9aad3343-7f7c-4b9d-9a26-0aa4e6f70720"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{"kms", "/.", 
   RowBox[{"fi", "->", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"kms", "/.", 
    RowBox[{"fi", "->", 
     RowBox[{"1", "/", "e"}]}]}], "]"}], "/.", 
  RowBox[{"e", "->", "0"}]}]}], "Input",
 CellChangeTimes->{{3.84172366241919*^9, 3.8417236784505157`*^9}},
 CellLabel->"In[52]:=",ExpressionUUID->"3b91607d-05f4-45ac-a403-5737fb41fb38"],

Cell[BoxData[
 RowBox[{
  FractionBox["be", "fe"], "+", "gi"}]], "Output",
 CellChangeTimes->{3.841723679127081*^9, 3.8417305515103493`*^9, 
  3.842617546621105*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"b50771a5-614b-44c4-8ce1-58dcf8198fea"],

Cell[BoxData[
 FractionBox[
  RowBox[{"be", "+", 
   RowBox[{"fe", " ", "gi"}], "+", "r"}], "fe"]], "Output",
 CellChangeTimes->{3.841723679127081*^9, 3.8417305515103493`*^9, 
  3.842617546638487*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"d8811883-5404-4dc3-92f4-f6f3bb171eb7"]
}, Open  ]]
},
WindowSize->{808, 911},
WindowMargins->{{345, Automatic}, {Automatic, 29}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"13.0 for Mac OS X x86 (64-bit) (December 2, 2021)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"a1b6f9ab-873f-4c48-9f8b-59a0a050b492"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 952, 20, 73, "Input",ExpressionUUID->"924e9c81-ef04-4688-93c3-7efd89ddaaa2"],
Cell[CellGroupData[{
Cell[1535, 44, 2965, 81, 157, "Input",ExpressionUUID->"b06d9ff6-8877-4719-894e-5211727747e7"],
Cell[4503, 127, 1835, 50, 78, "Output",ExpressionUUID->"1f255aba-caf6-4dd8-b637-6804ac683885"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6375, 182, 1208, 26, 136, "Input",ExpressionUUID->"bf030863-3ced-49b1-9389-64400c5e6cb7"],
Cell[7586, 210, 2259, 65, 78, "Output",ExpressionUUID->"cbd02ebe-9ce2-4c83-9a54-4de4c34057b9"],
Cell[9848, 277, 2411, 67, 81, "Output",ExpressionUUID->"1aa9c035-43bc-42e3-833e-b72b39c08dc8"],
Cell[12262, 346, 2350, 63, 83, "Output",ExpressionUUID->"3f87cec8-964a-46da-8a05-8ba328c77c87"],
Cell[14615, 411, 2207, 61, 78, "Output",ExpressionUUID->"54f8cf21-7527-4b15-a39c-b944c74513d7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16859, 477, 983, 22, 30, "Input",ExpressionUUID->"94688dc7-8fbc-49cc-b191-cb0d73c701b5"],
Cell[17845, 501, 570, 10, 53, "Output",ExpressionUUID->"b4e921e0-899e-4a9b-8c21-517ec60aba85"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18452, 516, 1400, 31, 73, "Input",ExpressionUUID->"b94d20ba-c28d-4fdc-864f-fba3ed0e73af"],
Cell[19855, 549, 1455, 35, 55, "Output",ExpressionUUID->"889837fe-9d8c-4483-add2-d61103d13f44"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21347, 589, 1035, 29, 73, "Input",ExpressionUUID->"c3a71aa8-b767-4017-af49-0aba25ceaf60"],
Cell[22385, 620, 441, 11, 64, "Output",ExpressionUUID->"01a40970-b947-47a2-a23c-c51bed538782"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22863, 636, 1166, 32, 73, "Input",ExpressionUUID->"571dc8cf-2a61-4bce-ae17-03ebcb13325e"],
Cell[24032, 670, 787, 21, 55, "Output",ExpressionUUID->"d654b2cf-2da4-4b15-9564-fc2dbf178214"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24856, 696, 1594, 46, 137, "Input",ExpressionUUID->"41049964-0d2a-4f8a-b10a-6033ba4fd2d2"],
Cell[26453, 744, 712, 16, 53, "Output",ExpressionUUID->"d1c90c8e-563b-4d24-b178-32d1e6b495d1"],
Cell[27168, 762, 1103, 30, 53, "Output",ExpressionUUID->"0a9900c8-0da0-4944-a662-835830b1b6f7"],
Cell[28274, 794, 409, 6, 34, "Output",ExpressionUUID->"6e0bb4a1-e23b-4c84-9d37-a5380a49f14f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28720, 805, 750, 17, 73, "Input",ExpressionUUID->"9908d898-a12b-499d-bc25-74c6c83e3fb2"],
Cell[29473, 824, 860, 22, 57, "Output",ExpressionUUID->"82e873ef-9e94-49a5-8db5-2c14bdd65f60"],
Cell[30336, 848, 2047, 57, 83, "Output",ExpressionUUID->"a524898f-6649-475c-bbf2-52a09fdd24f4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32420, 910, 449, 10, 52, "Input",ExpressionUUID->"b6f4d3a1-78d6-48af-a6df-7fea55907679"],
Cell[32872, 922, 1796, 51, 84, "Output",ExpressionUUID->"6e0bb4f6-61aa-44ca-8e3a-6801b0e953ad"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34705, 978, 717, 16, 73, "Input",ExpressionUUID->"5ae776ca-615d-4b60-86ee-dc72ea6f61f2"],
Cell[35425, 996, 740, 18, 57, "Output",ExpressionUUID->"445663b8-4c99-4224-b35b-767494e1dfd8"],
Cell[36168, 1016, 1017, 28, 57, "Output",ExpressionUUID->"4a12837d-b458-4a82-936f-4858f47e124b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37222, 1049, 431, 11, 52, "Input",ExpressionUUID->"d4ddfbcf-3f55-4396-abd1-c5f69bd313b7"],
Cell[37656, 1062, 1603, 46, 84, "Output",ExpressionUUID->"62e424ca-be27-43bd-a68d-7b3388762e5d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39296, 1113, 599, 15, 73, "Input",ExpressionUUID->"1a073019-4273-4117-9261-f6cdffaa9a40"],
Cell[39898, 1130, 849, 22, 57, "Output",ExpressionUUID->"94bc3816-8899-4ae5-aed8-3150097afe7a"],
Cell[40750, 1154, 1208, 32, 59, "Output",ExpressionUUID->"3177a9e3-778e-43b3-9308-0e53731105f0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41995, 1191, 449, 10, 52, "Input",ExpressionUUID->"8070985d-7ae3-4c2c-b1ec-213cc8187ede"],
Cell[42447, 1203, 1731, 50, 84, "Output",ExpressionUUID->"bb0fb9af-e37a-4439-94af-323393405de1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44215, 1258, 619, 15, 73, "Input",ExpressionUUID->"7d9685b3-0ae6-4cb3-b901-410e32455761"],
Cell[44837, 1275, 748, 19, 57, "Output",ExpressionUUID->"bec51ffb-b92b-4bd5-b936-2a02d12d0669"],
Cell[45588, 1296, 1026, 28, 55, "Output",ExpressionUUID->"a1a359df-a10d-424e-9647-f996ba288024"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46651, 1329, 454, 10, 52, "Input",ExpressionUUID->"104fb590-ca19-4489-ab8c-a5474e549b5e"],
Cell[47108, 1341, 1650, 48, 84, "Output",ExpressionUUID->"c68c0725-eada-453d-91e6-98c82e036c0b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48795, 1394, 815, 18, 73, "Input",ExpressionUUID->"43bc7323-b15e-4926-8c57-05f25f7e518f"],
Cell[49613, 1414, 802, 20, 57, "Output",ExpressionUUID->"9cabd51b-04b2-46d8-b1ff-aab3a4461679"],
Cell[50418, 1436, 2153, 58, 83, "Output",ExpressionUUID->"8068b907-b3e1-4dc7-80ff-7570d2b2be5c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52608, 1499, 452, 10, 52, "Input",ExpressionUUID->"bb2f8534-9250-470d-bf47-347440970eab"],
Cell[53063, 1511, 1965, 56, 84, "Output",ExpressionUUID->"8f782904-7ae0-4ca0-9982-e588c9545769"]
}, Open  ]],
Cell[55043, 1570, 390, 8, 30, "Input",ExpressionUUID->"3a4f5e8c-3ba2-48de-a864-e157ae41bcbe"],
Cell[CellGroupData[{
Cell[55458, 1582, 1352, 33, 115, "Input",ExpressionUUID->"048ba147-2f2c-4075-b303-4fe4e18356b1"],
Cell[56813, 1617, 1176, 20, 53, "Output",ExpressionUUID->"df2963e3-51eb-4bab-bf0c-2976e86f9f3a"],
Cell[57992, 1639, 1532, 36, 53, "Output",ExpressionUUID->"d854acfa-432f-4333-83e4-34c7954b57fb"],
Cell[59527, 1677, 1986, 46, 60, "Output",ExpressionUUID->"ed74cad0-3330-4e53-a10e-4827d877c3d2"],
Cell[61516, 1725, 968, 14, 34, "Output",ExpressionUUID->"44dc4eef-3dc1-4383-9487-14e4cae3fc03"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62521, 1744, 628, 15, 73, "Input",ExpressionUUID->"83b3b5bd-d0b4-4240-ba4c-7918208b5890"],
Cell[63152, 1761, 695, 20, 55, "Output",ExpressionUUID->"a35f2669-9f6a-48d3-9ef1-3798ede66c1f"],
Cell[63850, 1783, 1662, 52, 60, "Output",ExpressionUUID->"1705b2b2-c557-478c-bc84-688b1e719ed8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65549, 1840, 498, 11, 52, "Input",ExpressionUUID->"7b1341f2-d4c3-4ff3-af82-3f07f8668cfd"],
Cell[66050, 1853, 1664, 48, 84, "Output",ExpressionUUID->"ca389e68-265f-428e-94f1-3227883c63e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[67751, 1906, 654, 16, 73, "Input",ExpressionUUID->"75fada25-94e7-4b7f-80dd-7d454f6f33bb"],
Cell[68408, 1924, 670, 18, 57, "Output",ExpressionUUID->"fa061eab-0e79-4bf1-bf11-bfc334f6dc4d"],
Cell[69081, 1944, 835, 24, 57, "Output",ExpressionUUID->"e1759fe0-c57a-4e2d-929f-ae1138668d47"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69953, 1973, 594, 14, 52, "Input",ExpressionUUID->"6da88d09-2d47-44ec-9d0b-910de6d2728a"],
Cell[70550, 1989, 1474, 42, 84, "Output",ExpressionUUID->"f2ab2749-bf0e-4f19-a891-1a9a677a4bf0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72061, 2036, 604, 15, 73, "Input",ExpressionUUID->"bd4a7575-8426-4c0d-8077-c5a8be1e72b1"],
Cell[72668, 2053, 638, 18, 55, "Output",ExpressionUUID->"5f88e300-86df-457e-b65f-7d403c26d62f"],
Cell[73309, 2073, 1336, 41, 59, "Output",ExpressionUUID->"eb505567-1512-4d95-b6f8-99e9a9d77109"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74682, 2119, 499, 11, 52, "Input",ExpressionUUID->"ea80bdc5-cdc9-41de-b339-d8a6b0d795b5"],
Cell[75184, 2132, 1841, 53, 84, "Output",ExpressionUUID->"0cc7b246-662e-4142-b3c9-d1e8d91961c3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77062, 2190, 552, 14, 73, "Input",ExpressionUUID->"0e43c2f4-f950-4ff0-885d-35af0c598a05"],
Cell[77617, 2206, 626, 19, 57, "Output",ExpressionUUID->"c970d07d-4fec-4840-9f22-e344d7feaeed"],
Cell[78246, 2227, 573, 17, 57, "Output",ExpressionUUID->"fdb15631-5758-435a-95f6-f955d7354da2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78856, 2249, 340, 7, 52, "Input",ExpressionUUID->"d42b1db2-b558-412c-8ca9-2ef779bd6982"],
Cell[79199, 2258, 1549, 45, 84, "Output",ExpressionUUID->"8b5ec658-7fa2-4040-82c2-8293974171b3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80785, 2308, 601, 15, 52, "Input",ExpressionUUID->"b5138c99-1841-429b-868d-e018940649b0"],
Cell[81389, 2325, 498, 13, 51, "Output",ExpressionUUID->"7f6cdc62-df1a-4a32-9e05-edef3c2ea9ed"]
}, Open  ]],
Cell[81902, 2341, 290, 6, 30, "Input",ExpressionUUID->"6058b5a8-f78c-4757-9fd1-3b0ccefb6fa4"],
Cell[CellGroupData[{
Cell[82217, 2351, 448, 11, 52, "Input",ExpressionUUID->"405fea11-26c7-4ba1-aa07-76f6b5cf6a7d"],
Cell[82668, 2364, 271, 5, 51, "Output",ExpressionUUID->"fd9ac717-b1a8-481d-b259-72f6f0de144d"],
Cell[82942, 2371, 422, 11, 53, "Output",ExpressionUUID->"9aad3343-7f7c-4b9d-9a26-0aa4e6f70720"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83401, 2387, 451, 11, 52, "Input",ExpressionUUID->"3b91607d-05f4-45ac-a403-5737fb41fb38"],
Cell[83855, 2400, 244, 5, 51, "Output",ExpressionUUID->"b50771a5-614b-44c4-8ce1-58dcf8198fea"],
Cell[84102, 2407, 279, 6, 51, "Output",ExpressionUUID->"d8811883-5404-4dc3-92f4-f6f3bb171eb7"]
}, Open  ]]
}
]
*)

